.. include:: /ad/ad_attention.inc

.. _diagnostics:

======================
`plasmapy.diagnostics`
======================

.. toctree::
   :maxdepth: 1
   :caption: Sub-Packages & Modules

   Charged particle radiography <charged_particle_radiography/index>
   Swept Langmuir (will be deprecated) <langmuir>
   thomson

API
---

.. automodapi:: plasmapy.diagnostics
   :heading-chars: ^~
